# Emojipy
An Async API wrapper for emoji.gg. Useful for Discord Bots, or just trying to get some fun information


# Installation
`pip install emojigg`

# Docs?
I'm still working on docs, but in the mean time I've setup the wiki -> https://github.com/NextChai/Emojigg/wiki

